@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: simple-sendfile
-version: 0.2.21
-id: simple-sendfile-0.2.21-b4189a70d5e750749d989e840422f185
-key: simpl_1s4YZSsjn6TCbK7MVn1EXz
+version: 0.2.22
+id: simple-sendfile-0.2.22-5543b22c4382748239d6fed42d7bf1f0
+key: simpl_4VYduwsMhnIC5qGgDYCFZo
 license: BSD3
 maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
 synopsis: Cross platform library for the sendfile system call
@@ -15,13 +15,13 @@ category: Network
 author: Kazu Yamamoto <kazu@iij.ad.jp>
 exposed: True
 exposed-modules:
-    Network.Sendfile
+    Network.Sendfile System.Linux.Sendfile
 hidden-modules: Network.Sendfile.Types Network.Sendfile.Linux
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/simple-sendfile-0.2.21
-library-dirs: /usr/lib/ghc-7.10.3/site-local/simple-sendfile-0.2.21
-data-dir: /usr/share/arm-linux-ghc-7.10.3/simple-sendfile-0.2.21
-hs-libraries: HSsimple-sendfile-0.2.21-1s4YZSsjn6TCbK7MVn1EXz
+import-dirs: /usr/lib/ghc-7.10.3/site-local/simple-sendfile-0.2.22
+library-dirs: /usr/lib/ghc-7.10.3/site-local/simple-sendfile-0.2.22
+data-dir: /usr/share/arm-linux-ghc-7.10.3/simple-sendfile-0.2.22
+hs-libraries: HSsimple-sendfile-0.2.22-4VYduwsMhnIC5qGgDYCFZo
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
